# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.organization_settings_api import OrganizationSettingsApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestOrganizationSettingsApi(unittest.TestCase):
    """OrganizationSettingsApi unit test stubs"""

    def setUp(self):
        self.api = OrganizationSettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_many_base_organization_setting_controller_organization_setting(self):
        """Test case for create_many_base_organization_setting_controller_organization_setting

        Create many OrganizationSetting  # noqa: E501
        """
        pass

    def test_create_one_base_organization_setting_controller_organization_setting(self):
        """Test case for create_one_base_organization_setting_controller_organization_setting

        Create one OrganizationSetting  # noqa: E501
        """
        pass

    def test_delete_one_base_organization_setting_controller_organization_setting(self):
        """Test case for delete_one_base_organization_setting_controller_organization_setting

        Delete one OrganizationSetting  # noqa: E501
        """
        pass

    def test_get_many_base_organization_setting_controller_organization_setting(self):
        """Test case for get_many_base_organization_setting_controller_organization_setting

        Retrieve many OrganizationSetting  # noqa: E501
        """
        pass

    def test_get_one_base_organization_setting_controller_organization_setting(self):
        """Test case for get_one_base_organization_setting_controller_organization_setting

        Retrieve one OrganizationSetting  # noqa: E501
        """
        pass

    def test_organization_setting_controller_get_unscoped_organization_settings(self):
        """Test case for organization_setting_controller_get_unscoped_organization_settings

        Retrieve all organization settings  # noqa: E501
        """
        pass

    def test_organization_setting_controller_get_versions(self):
        """Test case for organization_setting_controller_get_versions

        Retrieve container versions  # noqa: E501
        """
        pass

    def test_replace_one_base_organization_setting_controller_organization_setting(self):
        """Test case for replace_one_base_organization_setting_controller_organization_setting

        Replace one OrganizationSetting  # noqa: E501
        """
        pass

    def test_update_one_base_organization_setting_controller_organization_setting(self):
        """Test case for update_one_base_organization_setting_controller_organization_setting

        Update one OrganizationSetting  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
